"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commit_1 = require("../commit");
const config_1 = require("../config");
class DetectChangedFilesCommand {
    static run(commandLineConfig) {
        try {
            const config = config_1.loadConfig(commandLineConfig);
            const changedFiles = commit_1.getChangedFiles(config.commits[0], config.commits[1]);
            if (config.showDefaultOutput) {
                DetectChangedFilesCommand.printTitle(config.commits[0], config.commits[1]);
                changedFiles.forEach((file) => console.log(file));
            }
            if (config.handle) {
                config.handle({ changedFiles, commits: [config.commits[0], config.commits[1]] });
            }
        }
        catch (error) {
            console.log(error.message);
        }
    }
    static printTitle(commitId1, commitId2) {
        commitId1 = commit_1.isLatestCommit(commitId1) ? 'latest commit' : commit_1.isLatestTag(commitId1) ? 'latest tag' : commitId1;
        commitId2 = commit_1.isLatestCommit(commitId2) ? 'latest commit' : commit_1.isLatestTag(commitId2) ? 'latest tag' : commitId2;
        console.log(`------- Changed files between ${chalk_1.default.cyanBright.bold(commitId1)} & ${chalk_1.default.cyanBright.bold(commitId2)} -------`);
    }
}
exports.default = DetectChangedFilesCommand;
