"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getChangedFiles = exports.isLatestTag = exports.isLatestCommit = exports.getCommitIdOfLatestCommit = exports.getCommitIdOfLatestTag = void 0;
const shelljs_1 = require("shelljs");
const error_1 = require("./error");
const getCommitIdOfLatestTag = () => {
    const tagName = shelljs_1.exec('git describe --tags --abbrev=0', { silent: true }).trimEnd();
    const commitId = shelljs_1.exec(`git rev-list -n 1 ${tagName}`, { silent: true }).trimEnd();
    if (commitId) {
        return commitId;
    }
    throw new Error(error_1.ERROR_MESSAGE_TAG_NOT_FOUND);
};
exports.getCommitIdOfLatestTag = getCommitIdOfLatestTag;
const getCommitIdOfLatestCommit = () => {
    return shelljs_1.exec(`git rev-parse HEAD`, { silent: true }).trimEnd();
};
exports.getCommitIdOfLatestCommit = getCommitIdOfLatestCommit;
const isLatestCommit = (commitId) => {
    return commitId === 'HEAD';
};
exports.isLatestCommit = isLatestCommit;
const isLatestTag = (commitId) => {
    return commitId === 'TAG';
};
exports.isLatestTag = isLatestTag;
const getChangedFiles = (commitId1, commitId2) => {
    commitId1 = exports.isLatestCommit(commitId1)
        ? exports.getCommitIdOfLatestCommit()
        : exports.isLatestTag(commitId1)
            ? exports.getCommitIdOfLatestTag()
            : commitId1;
    commitId2 = exports.isLatestCommit(commitId2)
        ? exports.getCommitIdOfLatestCommit()
        : exports.isLatestTag(commitId2)
            ? exports.getCommitIdOfLatestTag()
            : commitId2;
    if (commitId1 === commitId2) {
        throw new Error(error_1.ERROR_MESSAGE_COMMIT_IDENTICAL);
    }
    const output = shelljs_1.exec(`git diff --name-only ${commitId1} ${commitId2}`, { silent: true }).trimEnd();
    return output.split('\n');
};
exports.getChangedFiles = getChangedFiles;
